clear
format short
echo off
warning off

% This file runs the function 'N_model.' See comments at beginning of N_model.m to see what
% that file does.  This file ('run_Nmodel') sends the following arguments to N_model.  N_model
% returns the argument 'simseries'.  Simseries is, for each level of N concentration, the value
% or cumulative amount of several state variables taken at end of an N_model simulation time series.

%  Currently, this script file is designed to run 'N_model' at several combinations of N and mr, where
%  N and mr are varied in a factorial manner.  N is the concentration of available nitrogen (i.e.,
%  not including complex organic N) in water flowing into the subsurface zone of a gravel bar,
%  and mr is the root mortality rate constant.  Note, with some simple changes, we can also have this
%  script run 'N_model'across a range of kd (decomposition rate constant).

for mtyp=0:1; % model type: 0 for constant model; 1 for response model
    mrlist=(.0001:.0001:.002); % vary mr (root mortality) from 0.0001 to 0.002 per day, in increments
    %% of 0.0001
    for mrj=1:length(mrlist);
        modeltype=mtyp; % 0 for constant model; 1 for response model
        ss_mode=0; % 0 to run model for pre-specified number of days, 1 to run model to steady state
        numdays=1825; % in ss_mode=0, 'numdays' specifies the number of days to run N_model
        %% for each level of N concentration. In ss_mode=1 (run to steady state), 'numdays' specifies
        %% the day number on which to give up looking for steady state and terminate the simulation.
        %% Thus, when ss_mode=1, I suggest numdays=9125.  You, as the model user, don't want
        %% to wait forever for the model to run. If model hasn't found steady state by day 9125
        %% (25 years), then just bail out.
        minN=0.01; % minimum N concentration at which to run N_model
        maxN=1; % maximum N concentration at which to run N_model
        incr=0.03; % increments between all values (within the range [minN maxN]) at which N_model is run
        mr=mrlist(mrj); % rate constant for root mortality - proportion of root standing stock that dies each day
        kd=0.00252; % rate constant for organic matter decomp - proportion of OM that decomposes each day
        initialR=0; % intial mass (g) of root pool
        initialOM=0; % intial mass (g) of organic matter pool
        initialPMass=0; % initial mass (g) of plant (roots + shoots)
        
        if modeltype==0;disp('Constant Model');else disp('Response Model');end
        if ss_mode==0;disp('run model for the following number of days'),disp(numdays)
        else disp('run model to steady state (dP/dt < 0.0001) - or break at day number ='),disp(numdays)
        end
        
        simseries = N_model(modeltype,ss_mode,numdays,minN,maxN,incr,mr,kd,initialR,initialOM,initialPMass);
        
        if mtyp==0;
            if mrj==1
                save mr1_5ycons.txt simseries -ascii -tabs;
                %% file naming convention mr1_5ycons, means the 1st level (mr=0.0001) of the mr
                %% values used, the model was run for 5 years, and the constant model was run.
                %% Another example would be mr5_ssresp: 5th level of the mr values, model run to
                %% steady state, and response model was run.
            elseif mrj==2
                save mr2_5ycons.txt simseries -ascii -tabs;
            elseif mrj==3
                save mr3_5ycons.txt simseries -ascii -tabs;
            elseif mrj==4
                save mr4_5ycons.txt simseries -ascii -tabs;
            else save mr5_5ycons.txt simseries -ascii -tabs;
            end
        else
            if mrj==1
                save mr1_5yresp.txt simseries -ascii -tabs;
            elseif mrj==2
                save mr2_5yresp.txt simseries -ascii -tabs;
            elseif mrj==3
                save mr3_5yresp.txt simseries -ascii -tabs;
            elseif mrj==4
                save mr4_5yresp.txt simseries -ascii -tabs;
            else save mr5_5yresp.txt simseries -ascii -tabs;
            end
        end
    end
end

% set(0,'DefaultLineLineWidth',2.5)
% figure(14)
% subplot(2,2,1)
% plot (simseries(:,1),simseries(:,4),'k-',simseries(:,1),simseries(:,3),'k:')
% xlabel('N concentration (mg / L)')
% ylabel('N input (g) during 5 y')
% title('solid: recyc+hydro, dot: recycled')
% 
% subplot(2,2,2)
% plot (simseries(:,1),simseries(:,5),'k-',simseries(:,1),simseries(:,11),'k:')
% xlabel('N concentration (mg / L)')
% ylabel('N loss (g) during 5 y')
% title('solid: denitrif, dot: plant uptake')
% 
% subplot(2,2,3)
% plot (simseries(:,1),simseries(:,15),'k-',simseries(:,1),simseries(:,16),'k:')
% xlabel('N concentration (mg / L)')
% ylabel('flux of N (g) during 5y')
% title('solid: N export, dot: N retention')
% 
% subplot(2,2,4)
% plot (simseries(:,1),simseries(:,17),'k-')
% xlabel('N concentration (mg / L)')
% ylabel('% of 5-y input of N retained')
% 
% figure(15)
% subplot(2,2,1)
% plotyy (simseries(:,1),simseries(:,7),simseries(:,1),simseries(:,27))
% [AX,H1,H2] = plotyy(simseries(:,1),simseries(:,7),simseries(:,1),simseries(:,27));
% set(get(AX(1),'Ylabel'),'String','plant production (g) during 5y')
% set(get(AX(2),'Ylabel'),'String','dP/dt (g/d^2) on day 1825')
% set(AX(1),'YColor','black'); set(AX(2),'YColor','black')
% set(H1,'LineStyle','-'); set(H2,'LineStyle',':')
% set(H1,'Color','k'); set(H2,'Color','k')
% xlabel('N concentration (mg / L)')
% title('solid: P, dot: dP/dt')
% 
% subplot(2,2,2)
% plot (simseries(:,1),simseries(:,8),'k-')
% xlabel('N concentration (mg / L)')
% ylabel('plant mass (g) on day 1825')
% 
% subplot(2,2,3)
% plot (simseries(:,1),simseries(:,21),'k-',simseries(:,1),simseries(:,26),'k:')
% xlabel('N concentration (mg / L)')
% ylabel('mass (g) on day 1825')
% title('solid: roots, dot: OM')
% 
% subplot(2,2,4)
% plot (simseries(:,1),simseries(:,20),'k-',simseries(:,1),simseries(:,25),'k:')
% xlabel('N concentration (mg / L)')
% ylabel('change in pool size (g/d) on day 1825')
% title('solid: roots, dot: OM')
% 
% figure(16)
% subplot(2,2,1)
% plot (simseries(:,1),simseries(:,18),'k-',simseries(:,1),simseries(:,19),'k--',simseries(:,1),simseries(:,24),'k:')
% xlabel('N concentration (mg / L)')
% ylabel('flux (g) during 5y')
% title('solid: root prod, dash: root-to-OM, dot: OM decomp')
% 
% subplot(2,2,2)
% plot (simseries(:,1),simseries(:,14),'k-',simseries(:,1),simseries(:,9),'k:')
% xlabel('N concentration (mg / L)')
% ylabel('proportional N content of tissue')
% title('solid: whole plant, dot: produced on day 1825')
% 
% subplot(2,2,3)
% plot (simseries(:,1),simseries(:,10),'k-')
% xlabel('N concentration (mg / L)')
% ylabel('prop day 1825 prod allocated to roots')
% 
% subplot(2,2,4)
% plot (simseries(:,1),simseries(:,12),'k-')
% xlabel('N concentration (mg / L)')
% ylabel('mass of N in plant tissue (g) on day 1825')